pub struct ResolvedToolSet { /* private fields */ }Expand description
Immutable tool set resolved at admission from the host registry.
Implementations
Sourceimpl ResolvedToolSet
impl ResolvedToolSet
Sourcepub fn from_registered(tools: Vec<RegisteredTool>) -> Self
pub fn from_registered(tools: Vec<RegisteredTool>) -> Self
Build from registered tools selected by request tool ids (already validated).
Sourcepub fn tools(&self) -> Vec<&ResolvedTool>
pub fn tools(&self) -> Vec<&ResolvedTool>
Ordered resolved tools.
Sourcepub fn get(&self, id: &ToolId) -> Option<&ResolvedTool>
pub fn get(&self, id: &ToolId) -> Option<&ResolvedTool>
Lookup by id.
Sourcepub fn get_by_name(&self, name: &ToolName) -> Option<&ResolvedTool>
pub fn get_by_name(&self, name: &ToolName) -> Option<&ResolvedTool>
Lookup by name.
Sourcepub fn contains_name(&self, name: &ToolName) -> bool
pub fn contains_name(&self, name: &ToolName) -> bool
Whether name is allowlisted.