TransactionToolDispatcher

Struct TransactionToolDispatcher 

pub struct TransactionToolDispatcher { /* private fields */ }
Transaction-owned dispatcher: allowlist, validation, capacity, handler, output check.

Implementations

Source

impl TransactionToolDispatcher

pub fn new( transaction_id: TransactionId, session_key: SessionKey, tools: ResolvedToolSet, shared_capacity: Arc<SharedToolCapacity>, max_concurrent_tools: usize, max_queued_tools: usize, ) -> Arc<Self>

Build a dispatcher for one admitted transaction.

pub fn with_limits( transaction_id: TransactionId, session_key: SessionKey, tools: ResolvedToolSet, shared_capacity: Arc<SharedToolCapacity>, limits: DispatcherLimits, ) -> Arc<Self>

Build with explicit concurrency and payload/output caps (D-015).

pub fn tools(&self) -> &ResolvedToolSet

Resolved tool set (encoder / MCP projection).

pub fn transaction_id(&self) -> TransactionId

Transaction identity.

pub fn session_key(&self) -> &SessionKey

Session key.

pub async fn dispatch( self: &Arc<Self>, request: DispatchRequest, ) -> DispatchOutcome

Dispatch one call end-to-end.

pub async fn dispatch_with_cancel( self: &Arc<Self>, request: DispatchRequest, cancel: Option<Arc<Notify>>, ) -> DispatchOutcome

Dispatch with an optional external cancel signal (D-028).

When cancel is notified, the dispatcher runs the same termination path as an execution deadline so the worker is cancel/kill/joined instead of detached.